@@ -22,7 +22,7 @@
 
 // KDE
 #include <ktoggleaction.h>
-#include <QDebug>
+#include "konqdebug.h"
 #include <QIcon>
 #include <kiconloader.h>
 #include <KLocalizedString>
@@ -131,7 +131,7 @@ ToggleViewGUIClient::ToggleViewGUIClient(KonqMainWindow *mainWindow)
     for (; cIt != cEnd; ++cIt) {
         QString description = i18n("Show %1", (*cIt)->name());
         QString name = (*cIt)->desktopEntryName();
-        //qDebug() << "ToggleViewGUIClient: name=" << name;
+        //qCDebug(KONQUEROR_LOG) << "ToggleViewGUIClient: name=" << name;
         KToggleAction *action = new KToggleAction(description, this);
         mainWindow->actionCollection()->addAction(name.toLatin1(), action);
 
@@ -217,7 +217,7 @@ void ToggleViewGUIClient::slotToggleView(bool toggle)
             viewManager->setActivePart(childView->part());
         }
 
-        qDebug() << "ToggleViewGUIClient::slotToggleView setToggleView(true) on " << childView;
+        qCDebug(KONQUEROR_LOG) << "ToggleViewGUIClient::slotToggleView setToggleView(true) on " << childView;
         childView->setToggleView(true);
 
         m_mainWindow->viewCountChanged();
