@@ -33,7 +33,7 @@
 
 #include <kio/job.h>
 #include <kio/jobuidelegate.h>
-#include <QDebug>
+#include "konqdebug.h"
 #include <kcursor.h>
 #include <kmessagebox.h>
 #include <KLocalizedString>
@@ -121,7 +121,7 @@ KonqView::KonqView(KonqViewFactory &viewFactory,
 
 KonqView::~KonqView()
 {
-    //qDebug() << "part=" << m_pPart;
+    //qCDebug(KONQUEROR_LOG) << "part=" << m_pPart;
 
     // We did so ourselves for passive views
     if (m_pPart != 0L) {
@@ -141,13 +141,13 @@ KonqView::~KonqView()
     m_lstHistory.clear();
 
     setRun(0L);
-    //qDebug() << this << "done";
+    //qCDebug(KONQUEROR_LOG) << this << "done";
 }
 
 void KonqView::openUrl(const QUrl &url, const QString &locationBarURL,
                        const QString &nameFilter, bool tempFile)
 {
-    qDebug() << "url=" << url << "locationBarURL=" << locationBarURL;
+    qCDebug(KONQUEROR_LOG) << "url=" << url << "locationBarURL=" << locationBarURL;
 
     setPartMimeType();
 
@@ -171,7 +171,7 @@ void KonqView::openUrl(const QUrl &url, const QString &locationBarURL,
     }
 
 #ifdef DEBUG_HISTORY
-    qDebug() << "m_bLockedLocation=" << m_bLockedLocation << "browserArgs.lockHistory()=" << browserArgs.lockHistory();
+    qCDebug(KONQUEROR_LOG) << "m_bLockedLocation=" << m_bLockedLocation << "browserArgs.lockHistory()=" << browserArgs.lockHistory();
 #endif
     if (browserArgs.lockHistory()) {
         lockHistory();
@@ -218,7 +218,7 @@ void KonqView::openUrl(const QUrl &url, const QString &locationBarURL,
         if (url.isLocalFile()) {
             m_tempFile = url.toLocalFile();
         } else {
-            qWarning() << "Tempfile option is set, but URL is remote:" << url;
+            qCWarning(KONQUEROR_LOG) << "Tempfile option is set, but URL is remote:" << url;
         }
     }
 
@@ -231,7 +231,7 @@ void KonqView::openUrl(const QUrl &url, const QString &locationBarURL,
     KonqHistoryManager::kself()->addPending(url, locationBarURL, QString());
 
 #ifdef DEBUG_HISTORY
-    qDebug() << "Current position:" << historyIndex();
+    qCDebug(KONQUEROR_LOG) << "Current position:" << historyIndex();
 #endif
 
 #ifdef KActivities_FOUND
@@ -245,7 +245,7 @@ void KonqView::openUrl(const QUrl &url, const QString &locationBarURL,
 
 void KonqView::switchView(KonqViewFactory &viewFactory)
 {
-    //qDebug();
+    //qCDebug(KONQUEROR_LOG);
     KParts::ReadOnlyPart *oldPart = m_pPart;
     KParts::ReadOnlyPart *part = m_pKonqFrame->attach(viewFactory);   // creates the part
     if (!part) {
@@ -272,7 +272,7 @@ void KonqView::switchView(KonqViewFactory &viewFactory)
 
     prop = m_service->property(QStringLiteral("X-KDE-BrowserView-FollowActive"));
     if (prop.isValid() && prop.toBool()) {
-        //qDebug() << "X-KDE-BrowserView-FollowActive -> setFollowActive";
+        //qCDebug(KONQUEROR_LOG) << "X-KDE-BrowserView-FollowActive -> setFollowActive";
         setFollowActive(true);
     }
 
@@ -283,7 +283,7 @@ void KonqView::switchView(KonqViewFactory &viewFactory)
         // Honor "non-removable passive mode" (like the dirtree)
         prop = m_service->property(QStringLiteral("X-KDE-BrowserView-PassiveMode"));
         if (prop.isValid() && prop.toBool()) {
-            qDebug() << "X-KDE-BrowserView-PassiveMode -> setPassiveMode";
+            qCDebug(KONQUEROR_LOG) << "X-KDE-BrowserView-PassiveMode -> setPassiveMode";
             setPassiveMode(true);   // set as passive
         }
 
@@ -321,7 +321,7 @@ bool KonqView::changePart(const QString &mimeType,
     // Caller should call stop first.
     Q_ASSERT(!m_bLoading);
 
-    //qDebug() << "mimeType=" << mimeType
+    //qCDebug(KONQUEROR_LOG) << "mimeType=" << mimeType
     //             << "requested serviceName=" << serviceName
     //             << "current service name=" << m_service->desktopEntryName();
 
@@ -331,7 +331,7 @@ bool KonqView::changePart(const QString &mimeType,
     }
 
     if (isLockedViewMode()) {
-        //qDebug() << "This view's mode is locked - can't change";
+        //qCDebug(KONQUEROR_LOG) << "This view's mode is locked - can't change";
         return false; // we can't do that if our view mode is locked
     }
 
@@ -351,7 +351,7 @@ bool KonqView::changePart(const QString &mimeType,
     // Check if that's already the kind of part we have -> no need to recreate it
     // Note: we should have an operator== for KService...
     if (m_service && m_service->entryPath() == service->entryPath()) {
-        qDebug() << "Reusing service. Service type set to" << m_serviceType;
+        qCDebug(KONQUEROR_LOG) << "Reusing service. Service type set to" << m_serviceType;
         if (m_pMainWindow->currentView() == this) {
             m_pMainWindow->updateViewModeActions();
         }
@@ -366,7 +366,7 @@ bool KonqView::changePart(const QString &mimeType,
 
 void KonqView::connectPart()
 {
-    //qDebug();
+    //qCDebug(KONQUEROR_LOG);
     connect(m_pPart, SIGNAL(started(KIO::Job*)),
             this, SLOT(slotStarted(KIO::Job*)));
     connect(m_pPart, SIGNAL(completed()),
@@ -509,12 +509,12 @@ void KonqView::slotResizeTopLevelWidget(int w, int h)
 
 void KonqView::slotStarted(KIO::Job *job)
 {
-    //qDebug() << job;
+    //qCDebug(KONQUEROR_LOG) << job;
     setLoading(true);
 
     if (job) {
         // Manage passwords properly...
-        //qDebug() << "Window ID =" << m_pMainWindow->window()->winId();
+        //qCDebug(KONQUEROR_LOG) << "Window ID =" << m_pMainWindow->window()->winId();
         KJobWidgets::setWindow(job, m_pMainWindow->window());
 
         connect(job, SIGNAL(percent(KJob*,ulong)), this, SLOT(slotPercent(KJob*,ulong)));
@@ -530,7 +530,7 @@ void KonqView::slotRequestFocus(KParts::ReadOnlyPart *)
 
 void KonqView::setLoading(bool loading, bool hasPending /*= false*/)
 {
-    //qDebug() << "loading=" << loading << "hasPending=" << hasPending;
+    //qCDebug(KONQUEROR_LOG) << "loading=" << loading << "hasPending=" << hasPending;
     m_bLoading = loading;
     m_bPendingRedirection = hasPending;
     if (m_pMainWindow->currentView() == this) {
@@ -540,7 +540,7 @@ void KonqView::setLoading(bool loading, bool hasPending /*= false*/)
         if (loading) {
             QWidget *partWidget = (m_pPart ? m_pPart->widget() : 0);
             if (partWidget && !partWidget->hasFocus()) {
-                //qDebug() << "SET FOCUS on the widget";
+                //qCDebug(KONQUEROR_LOG) << "SET FOCUS on the widget";
                 partWidget->setFocus();
             }
         }
@@ -571,7 +571,7 @@ void KonqView::slotCompleted()
 
 void KonqView::slotCompleted(bool hasPending)
 {
-    //qDebug() << "hasPending=" << hasPending;
+    //qCDebug(KONQUEROR_LOG) << "hasPending=" << hasPending;
     m_pKonqFrame->statusbar()->slotLoadingProgress(-1);
 
     if (! m_bLockHistory) {
@@ -600,7 +600,7 @@ void KonqView::slotCompleted(bool hasPending)
 
 void KonqView::slotCanceled(const QString &errorMsg)
 {
-    //qDebug();
+    //qCDebug(KONQUEROR_LOG);
     // The errorMsg comes from the ReadOnlyPart (usually from its kio job, but not necessarily).
     // It should probably be used in a KMessageBox
     // Let's use the statusbar for now
@@ -629,10 +629,10 @@ void KonqView::setLocationBarURL(const QUrl &locationBarURL)
 
 void KonqView::setLocationBarURL(const QString &locationBarURL)
 {
-    //qDebug() << locationBarURL << "this=" << this;
+    //qCDebug(KONQUEROR_LOG) << locationBarURL << "this=" << this;
     m_sLocationBarURL = locationBarURL;
     if (m_pMainWindow->currentView() == this) {
-        //qDebug() << "is current view" << this;
+        //qCDebug(KONQUEROR_LOG) << "is current view" << this;
         m_pMainWindow->setLocationBarURL(m_sLocationBarURL);
         m_pMainWindow->setPageSecurity(m_pageSecurity);
     }
@@ -696,7 +696,7 @@ void KonqView::setCaption(const QString &caption)
 void KonqView::slotOpenURLNotify()
 {
 #ifdef DEBUG_HISTORY
-    qDebug();
+    qCDebug(KONQUEROR_LOG);
 #endif
     updateHistoryEntry(true);
     createHistoryEntry();
@@ -711,7 +711,7 @@ void KonqView::createHistoryEntry()
     HistoryEntry *current = currentHistoryEntry();
     if (current) {
 #ifdef DEBUG_HISTORY
-        qDebug() << "Truncating history";
+        qCDebug(KONQUEROR_LOG) << "Truncating history";
 #endif
         while (current != m_lstHistory.last()) {
             delete m_lstHistory.takeLast();
@@ -719,12 +719,12 @@ void KonqView::createHistoryEntry()
     }
     // Append a new entry
 #ifdef DEBUG_HISTORY
-    qDebug() << "Append a new entry";
+    qCDebug(KONQUEROR_LOG) << "Append a new entry";
 #endif
     appendHistoryEntry(new HistoryEntry);
     setHistoryIndex(m_lstHistory.count() - 1); // made current
 #ifdef DEBUG_HISTORY
-    qDebug() << "at=" << historyIndex() << "count=" << m_lstHistory.count();
+    qCDebug(KONQUEROR_LOG) << "at=" << historyIndex() << "count=" << m_lstHistory.count();
 #endif
 }
 
@@ -756,19 +756,19 @@ void KonqView::updateHistoryEntry(bool saveLocationBarURL)
     }
 
 #ifdef DEBUG_HISTORY
-    qDebug() << "Saving part URL:" << m_pPart->url() << "in history position" << historyIndex();
+    qCDebug(KONQUEROR_LOG) << "Saving part URL:" << m_pPart->url() << "in history position" << historyIndex();
 #endif
     current->url = m_pPart->url();
 
     if (saveLocationBarURL) {
 #ifdef DEBUG_HISTORY
-        qDebug() << "Saving location bar URL:" << m_sLocationBarURL << "in history position" << historyIndex();
+        qCDebug(KONQUEROR_LOG) << "Saving location bar URL:" << m_sLocationBarURL << "in history position" << historyIndex();
 #endif
         current->locationBarURL = m_sLocationBarURL;
         current->pageSecurity = m_pageSecurity;
     }
 #ifdef DEBUG_HISTORY
-    qDebug() << "Saving title:" << m_caption << "in history position" << historyIndex();
+    qCDebug(KONQUEROR_LOG) << "Saving title:" << m_caption << "in history position" << historyIndex();
 #endif
     current->title = m_caption;
     current->strServiceType = m_serviceType;
@@ -795,7 +795,7 @@ void KonqView::go(int steps)
 {
     if (!steps) { // [WildFox] i bet there are sites on the net with stupid devs who do that :)
 #ifdef DEBUG_HISTORY
-        qDebug() << "go(0) -> reload";
+        qCDebug(KONQUEROR_LOG) << "go(0) -> reload";
 #endif
         // [David] and you're right. And they expect that it reloads, apparently.
         // [George] I'm going to make nspluginviewer rely on this too. :-)
@@ -805,7 +805,7 @@ void KonqView::go(int steps)
 
     int newPos = historyIndex() + steps;
 #ifdef DEBUG_HISTORY
-    qDebug() << "steps=" << steps
+    qCDebug(KONQUEROR_LOG) << "steps=" << steps
              << "newPos=" << newPos
              << "m_lstHistory.count()=" << m_lstHistory.count();
 #endif
@@ -818,7 +818,7 @@ void KonqView::go(int steps)
     setHistoryIndex(newPos);   // sets current item
 
 #ifdef DEBUG_HISTORY
-    qDebug() << "New position" << historyIndex();
+    qCDebug(KONQUEROR_LOG) << "New position" << historyIndex();
 #endif
 
     restoreHistory();
@@ -830,14 +830,14 @@ void KonqView::restoreHistory()
     // the pointer points to will change with the following calls
 
 #ifdef DEBUG_HISTORY
-    qDebug() << "Restoring servicetype/name, and location bar URL from history:" << h.locationBarURL;
+    qCDebug(KONQUEROR_LOG) << "Restoring servicetype/name, and location bar URL from history:" << h.locationBarURL;
 #endif
     setLocationBarURL(h.locationBarURL);
     setPageSecurity(h.pageSecurity);
     m_sTypedURL.clear();
 
     if (!changePart(h.strServiceType, h.strServiceName)) {
-        qWarning() << "Couldn't change view mode to" << h.strServiceType << h.strServiceName;
+        qCWarning(KONQUEROR_LOG) << "Couldn't change view mode to" << h.strServiceType << h.strServiceName;
         return /*false*/;
     }
 
@@ -846,7 +846,7 @@ void KonqView::restoreHistory()
     aboutToOpenURL(h.url);
 
     if (h.reload == false && browserExtension()) {
-        //qDebug() << "Restoring view from stream";
+        //qCDebug(KONQUEROR_LOG) << "Restoring view from stream";
         QDataStream stream(h.buffer);
 
         browserExtension()->restoreState(stream);
@@ -864,7 +864,7 @@ void KonqView::restoreHistory()
     }
 
 #ifdef DEBUG_HISTORY
-    qDebug() << "New position (2)" << historyIndex();
+    qCDebug(KONQUEROR_LOG) << "New position (2)" << historyIndex();
 #endif
 }
 
@@ -925,7 +925,7 @@ void KonqView::setRun(KonqRun *run)
 
 void KonqView::stop()
 {
-    //qDebug();
+    //qCDebug(KONQUEROR_LOG);
     m_bAborted = false;
     finishedWithCurrentURL();
     if (m_bLoading || m_bPendingRedirection) {
@@ -933,7 +933,7 @@ void KonqView::stop()
         // we decided to keep it :)
         KonqHistoryManager::kself()->confirmPending(url(), m_sTypedURL);
 
-        //qDebug() << "m_pPart->closeUrl()";
+        //qCDebug(KONQUEROR_LOG) << "m_pPart->closeUrl()";
         m_pPart->closeUrl();
         m_bAborted = true;
         m_pKonqFrame->statusbar()->slotLoadingProgress(-1);
@@ -959,7 +959,7 @@ void KonqView::stop()
 void KonqView::finishedWithCurrentURL()
 {
     if (!m_tempFile.isEmpty()) {
-        qDebug() << "######### Deleting tempfile after use:" << m_tempFile;
+        qCDebug(KONQUEROR_LOG) << "######### Deleting tempfile after use:" << m_tempFile;
         QFile::remove(m_tempFile);
         m_tempFile.clear();
     }
@@ -1095,7 +1095,7 @@ bool KonqView::callExtensionURLMethod(const char *methodName, const QUrl &value)
 
 void KonqView::setViewName(const QString &name)
 {
-    //qDebug() << this << "name=" << name;
+    //qCDebug(KONQUEROR_LOG) << this << "name=" << name;
     if (m_pPart) {
         m_pPart->setObjectName(name);
     }
@@ -1180,7 +1180,7 @@ bool KonqView::eventFilter(QObject *obj, QEvent *e)
     if (!m_pPart) {
         return false;
     }
-//  qDebug() << "--" << obj->className() << "--" << e->type() << "--" ;
+//  qCDebug(KONQUEROR_LOG) << "--" << obj->className() << "--" << e->type() << "--" ;
     if (e->type() == QEvent::DragEnter && m_bURLDropHandling && obj == m_pPart->widget()) {
         QDragEnterEvent *ev = static_cast<QDragEnterEvent *>(e);
         const QMimeData *mimeData = ev->mimeData();
