@@ -32,12 +32,14 @@
 #include <QDebug>
 #include <QMultiHash>
 #include <QPointer>
+#include <QScopedPointer>
 
+class QAuthenticator;
 class QUrl;
 class WebSslInfo;
 class WebEnginePart;
 class QWebEngineDownloadItem;
-
+class KPasswdServerClient;
 
 class WebEnginePage : public QWebEnginePage
 {
@@ -60,13 +62,7 @@ public:
      */
     void setSslInfo (const WebSslInfo &other);
 
-    /**
-     * Reimplemented for internal reasons. The API is not affected.
-     *
-     * @internal
-     * @see KWebEnginePage::downloadRequest.
-     */
-    void downloadRequest(QWebEngineDownloadItem* request);
+    void download(const QUrl &url, bool newWindow = false);
 
 Q_SIGNALS:
     /**
@@ -75,6 +71,8 @@ Q_SIGNALS:
      */
     void loadAborted(const QUrl &url);
 
+    void navigationRequested(WebEnginePage* page, const QUrl& url);
+
 protected:
     /**
      * Returns the webengine part in use by this object.
@@ -105,6 +103,7 @@ protected Q_SLOTS:
     void slotUnsupportedContent(QNetworkReply* reply);
     virtual void slotGeometryChangeRequested(const QRect& rect);
     void slotFeaturePermissionRequested(const QUrl& url, QWebEnginePage::Feature feature);
+    void slotAuthenticationRequired(const QUrl &requestUrl, QAuthenticator *auth);
 
 private:
     bool checkLinkSecurity(const QNetworkRequest& req, NavigationType type) const;
@@ -120,6 +119,8 @@ private:
 
     WebSslInfo m_sslInfo;
     QPointer<WebEnginePart> m_part;
+
+    QScopedPointer<KPasswdServerClient> m_passwdServerClient;
 };
 
 
